spacepy.pycdf.gAttrList — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »

# spacepy.pycdf.gAttrList

class `spacepy.pycdf.` `gAttrList`(cdf_file, special_entry=None)

  Object representing all the gAttributes in a CDF.

  Normally accessed as an attribute of an open `CDF`:

        >>> global_attribs = cdffile.attrs

  Appears as a dictionary: keys are attribute names; each value is an attribute represented by a `gAttr` object. To access the global attribute TEXT:

      >>> text_attr = cdffile.attrs['TEXT']

  See also

  `AttrList`

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »